@@ -147,25 +147,6 @@
 #' sp_poly <- SpatialPolygons(list(poly1, poly2), 1:2)
 #' geojson_json(sp_poly)
 #'
-#' ## Another SpatialPolygons
-#' library("sp")
-#' library("rgeos")
-#' pt <- SpatialPoints(
-#'   coordinates(list(x = 0, y = 0)),
-#'   CRS("+proj=longlat +datum=WGS84")
-#' )
-#' ## transfrom to web mercator becuase geos needs project coords
-#' crs <- gsub(
-#'   "\n", "",
-#'   paste0("+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0
-#'   +y_0=0 +k=1.0 +units=m +nadgrids=@null +wktext +no_defs", collapse = "")
-#' )
-#' pt <- spTransform(pt, CRS(crs))
-#' ## buffer
-#' pt <- gBuffer(pt, width = 100)
-#' pt <- spTransform(pt, CRS("+proj=longlat +datum=WGS84"))
-#' geojson_json(pt)
-#'
 #' ## data.frame to geojson
 #' geojson_write(us_cities[1:2, ], lat = "lat", lon = "long") %>% as.json()
 #'
@@ -215,18 +196,6 @@
 #' sgdf <- SpatialGridDataFrame(sg, data.frame(val = 1:12))
 #' geojson_json(sgdf)
 #'
-#' # From SpatialRings
-#' library("rgeos")
-#' r1 <- Ring(cbind(x = c(1, 1, 2, 2, 1), y = c(1, 2, 2, 1, 1)), ID = "1")
-#' r2 <- Ring(cbind(x = c(1, 1, 2, 2, 1), y = c(1, 2, 2, 1, 1)), ID = "2")
-#' r1r2 <- SpatialRings(list(r1, r2))
-#' geojson_json(r1r2)
-#'
-#' # From SpatialRingsDataFrame
-#' dat <- data.frame(id = c(1, 2), value = 3:4)
-#' r1r2df <- SpatialRingsDataFrame(r1r2, data = dat)
-#' geojson_json(r1r2df)
-#'
 #' # From SpatialPixels
 #' library("sp")
 #' pixels <- suppressWarnings(
@@ -245,20 +214,6 @@
 #' )
 #' geojson_json(pixelsdf)
 #'
-#' # From SpatialCollections
-#' library("sp")
-#' library("rgeos")
-#' pts <- SpatialPoints(cbind(c(1, 2, 3, 4, 5), c(3, 2, 5, 1, 4)))
-#' poly1 <- Polygons(
-#'   list(Polygon(cbind(c(-100, -90, -85, -100), c(40, 50, 45, 40)))), "1"
-#' )
-#' poly2 <- Polygons(
-#'   list(Polygon(cbind(c(-90, -80, -75, -90), c(30, 40, 35, 30)))), "2"
-#' )
-#' poly <- SpatialPolygons(list(poly1, poly2), 1:2)
-#' dat <- SpatialCollections(pts, polygons = poly)
-#' geojson_json(dat)
-#'
 #' # From sf classes:
 #' if (require(sf)) {
 #'   ## sfg (a single simple features geometry)
@@ -448,44 +403,6 @@ geojson_json.sfg <- function(input, lat = NULL, lon = NULL, group = NULL,
   geoclass(as.json(geojson_list(input, precision = precision), ...), type)
 }
 
-# spatial classes from rgeos --------------------------
-#' @export
-geojson_json.SpatialRings <- function(input, lat = NULL, lon = NULL,
-                                      group = NULL, geometry = "point", type = "FeatureCollection",
-                                      convert_wgs84 = FALSE, crs = NULL, precision = NULL, ...) {
-  check_type_sp(type)
-  geoclass(geojson_rw(input,
-    target = "char", convert_wgs84 = convert_wgs84,
-    crs = crs, precision = precision
-  ), type = type)
-}
-
-#' @export
-geojson_json.SpatialRingsDataFrame <- function(input, lat = NULL, lon = NULL,
-                                               group = NULL, geometry = "point", type = "FeatureCollection",
-                                               convert_wgs84 = FALSE, crs = NULL, precision = NULL, ...) {
-  check_type_sp(type)
-  geoclass(geojson_rw(input,
-    target = "char", convert_wgs84 = convert_wgs84,
-    crs = crs, precision = precision
-  ), type = type)
-}
-
-#' @export
-geojson_json.SpatialCollections <- function(input, lat = NULL, lon = NULL,
-                                            group = NULL, geometry = "point", type = "FeatureCollection",
-                                            convert_wgs84 = FALSE, crs = NULL, precision = NULL, ...) {
-  check_type_sp(type)
-  lapply(
-    geojson_rw(input,
-      target = "char", convert_wgs84 = convert_wgs84, crs = crs,
-      precision = precision, ...
-    ),
-    geoclass,
-    type = type
-  )
-}
-
 # regular R classes --------------------------
 #' @export
 geojson_json.numeric <- function(input, lat = NULL, lon = NULL, group = NULL,
