@@ -153,17 +153,6 @@
 #'   )
 #'   map_gist(pixelsdf)
 #'
-#'   # From SpatialRings
-#'   library("rgeos")
-#'   r1 <- Ring(cbind(x = c(1, 1, 2, 2, 1), y = c(1, 2, 2, 1, 1)), ID = "1")
-#'   r2 <- Ring(cbind(x = c(1, 1, 2, 2, 1), y = c(1, 2, 2, 1, 1)), ID = "2")
-#'   r1r2 <- SpatialRings(list(r1, r2))
-#'   map_gist(r1r2)
-#'
-#'   # From SpatialRingsDataFrame
-#'   dat <- data.frame(id = c(1, 2), value = 3:4)
-#'   r1r2df <- SpatialRingsDataFrame(r1r2, data = dat)
-#'   map_gist(r1r2df)
 #' }
 #' }
 map_gist <- function(input, lat = "lat", lon = "long", geometry = "point",
@@ -263,25 +252,6 @@ map_gist.SpatialPixelsDataFrame <- function(input, lat = "lat", lon = "long", ge
   gistc(input, file, description, public, browse, ...)
 }
 
-# spatial classes methods from rgeos package --------------------------
-#' @export
-map_gist.SpatialRings <- function(input, lat = "lat", lon = "long", geometry = "point",
-                                  group = NULL, type = "FeatureCollection",
-                                  file = "myfile.geojson", description = "",
-                                  public = TRUE, browse = TRUE, ...) {
-  check4gistr()
-  gistc(input, file, description, public, browse, ...)
-}
-
-#' @export
-map_gist.SpatialRingsDataFrame <- function(input, lat = "lat", lon = "long", geometry = "point",
-                                           group = NULL, type = "FeatureCollection",
-                                           file = "myfile.geojson", description = "",
-                                           public = TRUE, browse = TRUE, ...) {
-  check4gistr()
-  gistc(input, file, description, public, browse, ...)
-}
-
 # R classes: numeric, data.frame, list ------------------------
 #' @export
 map_gist.numeric <- function(input, lat = "lat", lon = "long", geometry = "point", group = NULL,
